@@ -1,11 +1,13 @@
 package WordList::Phrase::ID::Proverb::KBBI;
 
 our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
+our %STATS = ("shortest_word_len",11,"num_words_contains_nonword_chars",1713,"num_words",1713,"num_words_contains_whitespace",1713,"avg_word_len",31.4284880326912,"longest_word_len",110,"num_words_contains_unicode",0); # STATS
+
 1;
 # ABSTRACT: Proverb phrases from Kamus Besar Bahasa Indonesia
 
@@ -22,7 +24,7 @@ WordList::Phrase::ID::Proverb::KBBI - Proverb phrases from Kamus Besar Bahasa In
 
 =head1 VERSION
 
-This document describes version 0.02 of WordList::Phrase::ID::Proverb::KBBI (from Perl distribution WordList-Phrase-ID-Proverb-KBBI), released on 2016-01-13.
+This document describes version 0.03 of WordList::Phrase::ID::Proverb::KBBI (from Perl distribution WordList-Phrase-ID-Proverb-KBBI), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
@@ -43,6 +45,22 @@ This document describes version 0.02 of WordList::Phrase::ID::Proverb::KBBI (fro
  # Get all the words
  my @all_words = $wl->all_words;
 
+=head1 STATISTICS
+
+ +----------------------------------+------------------+
+ | key                              | value            |
+ +----------------------------------+------------------+
+ | avg_word_len                     | 31.4284880326912 |
+ | longest_word_len                 | 110              |
+ | num_words                        | 1713             |
+ | num_words_contains_nonword_chars | 1713             |
+ | num_words_contains_unicode       | 0                |
+ | num_words_contains_whitespace    | 1713             |
+ | shortest_word_len                | 11               |
+ +----------------------------------+------------------+
+
+The statistics is available in the C<%STATS> package variable.
+
 =head1 SEE ALSO
 
 Converted from L<Games::Word::Phraselist::KBBI> 0.03.
